package com.ynet.life.sujrb.controller;

import com.ynet.gene.core.Context;
import com.ynet.gene.data.InvalidArgumentException;
import com.ynet.gene.data.ObjectNotFoundException;
import com.ynet.life.base.LifePlatManager;
import com.ynet.life.base.TEntity;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.log.LifeActionLoggerFactory;
import com.ynet.life.mvc.PlatXMLViewRequestController;
import com.ynet.life.mvc.SimpleRequest;
import com.ynet.life.sujrb.base.PBStandard;
import com.ynet.life.sujrb.memcached.PBMemCacheManager;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;

/* loaded from: com_ynet_life_sujrb_controller.jar:com/ynet/life/sujrb/controller/PerPlatCommonRequestController.class */
public class PerPlatCommonRequestController extends PlatXMLViewRequestController {
    protected void preActionWork(HttpServletRequest request, SimpleRequest simpleRequest) throws TranFailException {
    }

    protected void pstActionWork(HttpServletRequest request, Context context, Throwable throwable, SimpleRequest simpleRequest) throws TranFailException {
        LifeActionLoggerFactory.checkActionLogger(context, throwable);
    }

    protected void preContextWork(HttpServletRequest request, Context context, SimpleRequest simpleRequest) throws TranFailException {
        String isSign = request.getParameter(TEntity.IS_LOGIN);
        String bankId = request.getParameter(TEntity.bankIdFieldName);
        String channel = request.getParameter(TEntity.channelFieldname);
        if (bankId == null || "".equals(bankId)) {
            throw TEntity.BIZ_EXCEPTION_TRAN;
        }
        if (channel == null || "".equals(channel)) {
            throw TEntity.BIZ_EXCEPTION_TRAN;
        }
        context.put(TEntity.bankIdFieldName, bankId);
        context.put(TEntity.channelFieldname, channel);
        String dataSource = (String) LifePlatManager.BANK_DBSOURCE_MAP.get(bankId);
        context.put(TEntity.dataSourceName, dataSource);
        if (isSign != null && !isSign.equals(TEntity.isSign_OK)) {
            PBMemCacheManager pm = new PBMemCacheManager();
            if (pm.isConnServer()) {
                String customerId = request.getParameter(TEntity.customerIdFieldname);
                if (customerId == null || "".equals(customerId)) {
                    throw TEntity.BIZ_EXCEPTION_TRAN;
                }
                context.put(TEntity.customerIdFieldname, customerId);
                String key = String.valueOf(bankId) + "_" + channel + "_" + customerId;
                Map<String, Object> map = pm.get(key);
                if (map == null || map.size() == 0) {
                    Trace.log(getClass().getName(), "memcacahed is null ::".concat(String.valueOf(key)));
                }
            } else {
                Trace.log(getClass().getName(), "memcached不能连通服务端");
                throw TEntity.BIZ_EXCEPTION_MEMCACHED;
            }
        } else {
            String appKey = request.getParameter(TEntity.appKeyFieldname);
            if (appKey == null || "".equals(appKey)) {
                throw TEntity.BIZ_EXCEPTION_TRAN;
            }
            context.put(TEntity.appKeyFieldname, appKey);
        }
        String opId = String.valueOf(simpleRequest.getBizId()) + "|" + simpleRequest.getOpId();
        new StringBuilder(String.valueOf(bankId)).append("#").append(channel).append("#").append(opId);
    }

    protected void pstContextWork(HttpServletRequest request, Context context, SimpleRequest simpleRequest) throws TranFailException, ObjectNotFoundException, InvalidArgumentException {
        String isSign = request.getParameter(TEntity.IS_LOGIN);
        String customerId = (String) context.getDataValue(TEntity.customerIdFieldname);
        String bankId = request.getParameter(TEntity.bankIdFieldName);
        String channel = request.getParameter(TEntity.channelFieldname);
        PBMemCacheManager pm = new PBMemCacheManager();
        if (isSign != null && isSign.equals(TEntity.isSign_OK)) {
            if (pm.isConnServer()) {
                if (customerId == null || "".equals(customerId)) {
                    throw TEntity.BIZ_EXCEPTION_TRAN;
                }
                if (bankId == null || "".equals(bankId)) {
                    throw TEntity.BIZ_EXCEPTION_TRAN;
                }
                if (channel == null || "".equals(channel)) {
                    throw TEntity.BIZ_EXCEPTION_TRAN;
                }
                context.put(TEntity.customerIdFieldname, customerId);
                context.put(TEntity.bankIdFieldName, bankId);
                context.put(TEntity.channelFieldname, channel);
                String key = String.valueOf(bankId) + "_" + channel + "_" + customerId;
                Map<String, Object> map = new HashMap<>();
                ArrayList<String> list = (ArrayList) PBStandard.getCacheConList();
                pm.saveOrupdate(key, pm.synchrMemcachedFromContext(context, map, list));
                return;
            }
            Trace.log(getClass().getName(), "memcached不能连通服务端");
            throw TEntity.BIZ_EXCEPTION_MEMCACHED;
        }
        String key2 = String.valueOf(bankId) + "_" + channel + "_" + customerId;
        Map<String, Object> map2 = pm.get(key2);
        ArrayList<String> list2 = (ArrayList) PBStandard.getCacheConList();
        pm.saveOrupdate(key2, pm.synchrMemcachedFromContext(context, map2, list2));
    }

    private void addBusinessInfo(HttpServletRequest request, Context context, SimpleRequest simpleRequest) {
        try {
            request.getParameter("trxCode");
            request.getAttribute("srcChannel");
            simpleRequest.getId();
            context.put("timezone", request.getParameter("timezone"));
        } catch (Exception e) {
            Trace.logError("LifeAction", e.getMessage());
        }
    }
}
